Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(831)

Unified Diff: pkg/analyzer/lib/src/generated/constant.dart

Issue 679873002: Clone tokens when cloning ASTs for constants (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/lib/src/generated/constant.dart
diff --git a/pkg/analyzer/lib/src/generated/constant.dart b/pkg/analyzer/lib/src/generated/constant.dart
index 23dec9e39e5d3102509ff25020007ff2c5fa544f..374a1f925ed5c3b2c246797e6aa1965135a5b83a 100644
--- a/pkg/analyzer/lib/src/generated/constant.dart
+++ b/pkg/analyzer/lib/src/generated/constant.dart
@@ -900,10 +900,16 @@ class ConstantValueComputer {
}
/**
* [AstCloner] that copies the necessary information from the AST to allow const constructor
* initializers to be evaluated.
*/
class ConstantValueComputer_InitializerCloner extends AstCloner {
+ // TODO(brianwilkerson) Investigate replacing uses of this class with uses of
+ // AstCloner and ResolutionCopier.
+
+ ConstantValueComputer_InitializerCloner() : super(true);
+
@override
InstanceCreationExpression visitInstanceCreationExpression(InstanceCreationExpression node) {
InstanceCreationExpression expression = super.visitInstanceCreationExpression(node);
@@ -900,10 +900,16 @@ class ConstantValueComputer {
}
/**
- * [AstCloner] that copies the necessary information from the AST to allow const constructor
- * initializers to be evaluated.
+ * A `ConstantValueComputer_InitializerCloner` is an [AstCloner] that copies the
+ * necessary information from the AST to allow const constructor initializers to
+ * be evaluated.
*/
class ConstantValueComputer_InitializerCloner extends AstCloner {

Powered by Google App Engine
This is Rietveld 408576698